aboutsummaryrefslogtreecommitdiff
path: root/platform/linux-generic/include/api
diff options
context:
space:
mode:
authorOla Liljedahl <ola.liljedahl@linaro.org>2015-01-07 17:23:58 +0100
committerMike Holmes <mike.holmes@linaro.org>2015-01-07 12:05:50 -0500
commite034782a72075a654e8186997eb6e94b3e322ac0 (patch)
tree63bed49d3903f0e3eb6d5dfb5f79b477afa03704 /platform/linux-generic/include/api
parentfd46d82eb9f12405d919a0a45e6745391c52e18b (diff)
api: odp_system_info.h: change core to cpu everywhere
Rename odp_core_count() to odp_cpu_count(). Change "core" to "cpu"/"CPU" in messages and comments. Signed-off-by: Ola Liljedahl <ola.liljedahl@linaro.org> Reviewed-by: Petri Savolainen <petri.savolainen@linaro.org> Signed-off-by: Mike Holmes <mike.holmes@linaro.org>
Diffstat (limited to 'platform/linux-generic/include/api')
-rw-r--r--platform/linux-generic/include/api/odp_system_info.h8
-rw-r--r--platform/linux-generic/include/api/odp_thread.h6
2 files changed, 8 insertions, 6 deletions
diff --git a/platform/linux-generic/include/api/odp_system_info.h b/platform/linux-generic/include/api/odp_system_info.h
index bcd08d7f4..42ab05464 100644
--- a/platform/linux-generic/include/api/odp_system_info.h
+++ b/platform/linux-generic/include/api/odp_system_info.h
@@ -61,11 +61,13 @@ const char *odp_sys_cpu_model_str(void);
int odp_sys_cache_line_size(void);
/**
- * Core count
+ * CPU count
+ * Report the number of CPU's available to this ODP program.
+ * This may be smaller than the number of (online) CPU's in the system.
*
- * @return Core count
+ * @return Number of available CPU's
*/
-int odp_sys_core_count(void);
+int odp_sys_cpu_count(void);
/**
* @}
diff --git a/platform/linux-generic/include/api/odp_thread.h b/platform/linux-generic/include/api/odp_thread.h
index 2b7177d10..469d29864 100644
--- a/platform/linux-generic/include/api/odp_thread.h
+++ b/platform/linux-generic/include/api/odp_thread.h
@@ -31,11 +31,11 @@ int odp_thread_id(void);
/**
- * Get core id
+ * Get CPU number
*
* @return Core id where the thread is running currently
*/
-int odp_thread_core(void);
+int odp_thread_cpu(void);
/**
* @}
@@ -31,11 +31,11 @@ int odp_thread_id(void);
*
- * @return Core id where the thread is running currently
+ * @return CPU ID where the thread is currently running
*/